#
# See the file "LICENSE" for the full license governing this code.
#
module Puppet
  module Parser
    module Functions
      #
      # This function looks at the JVM options specified and removes
      # any options that are not supported by the specified JVM version
      #
      newfunction(:filter_usupported_jvm_options, :type => :rvalue) do |args|
        options      = args[0]
        jvm_version  = args[1]
        options_array = options.split(' ')
        case jvm_version
        when 7
          exclude = []
        when 8
          exclude = ['XX:MaxPermSize', 'XX:PermSize']
        else
          "Version #{jvm_version} is not supported. Only version 7 and 8 are."
        end
        filtered_options = options_array.select { |o| exclude.none?{ |e| o.include?(e) }}
        filtered_options.join(' ')
      end
    end
  end
end
