#
# See the file "LICENSE" for the full license governing this code.
#
#
#
#
class wls_install::support::files(
  $os_oracle_home            = $wls_install::support::params::osOracleHome,
  $ora_inventory             = $wls_install::support::params::oraInventory,
  $os_domain_type            = $wls_install::support::params::osDomainType,
  $os_log_folder             = $wls_install::support::params::osLogFolder,
  $os_download_folder        = $wls_install::support::params::osDownloadFolder,
  $os_mdw_home               = $wls_install::support::params::osMdwHome,
  $os_wl_home                = $wls_install::support::params::osWlHome,
  $ora_user                  = $wls_install::support::params::oraUser,
  $ora_group                 = $wls_install::support::params::oraGroup,
  $os_domain                 = $wls_install::support::params::osDomain,
  $os_domain_path            = $wls_install::support::params::osDomainPath,
  $node_mgr_path             = $wls_install::support::params::nodeMgrPath,
  $node_mgr_port             = $wls_install::support::params::nodeMgrPort,
  $node_mgr_address          = $wls_install::support::params::nodeMgrAddress,
  $wls_user                  = $wls_install::support::params::wlsUser,
  $wls_password              = $wls_install::support::params::wlsPassword,
  $wls_adminserver           = $wls_install::support::params::wlsAdminServer,
  $jsse_enabled              = $wls_install::support::params::jsseEnabled,
  $custom_trust              = false,
  $trust_keystore_file       = undef,
  $trust_keystore_passphrase = undef,
) inherits wls_install::support::params
{

  case $::kernel {
    'Linux', 'SunOS': {

    $mode             = '0775'

    $shell            = $wls_install::support::params::shell
    $userHome         = $wls_install::support::params::userHome
    $oraInstHome      = $wls_install::support::params::oraInstHome

    # lint:ignore:140chars
    if $custom_trust == true {
      $trust_env = "-Dweblogic.security.TrustKeyStore=CustomTrust -Dweblogic.security.CustomTrustKeyStoreFileName=${trust_keystore_file} -Dweblogic.security.CustomTrustKeystorePassPhrase=${trust_keystore_passphrase}"
    } else {
      $trust_env = ''
    }
    # lint:endignore

    if ! defined(File['/opt/scripts']) {
      file { '/opt/scripts':
        ensure  => directory,
        recurse => false,
        replace => false,
        owner   => $ora_user,
        group   => $ora_group,
        mode    => $mode,
      }
    }

    if ! defined(File['/opt/scripts/wls']) {
      file { '/opt/scripts/wls':
        ensure  => directory,
        recurse => false,
        replace => false,
        owner   => $ora_user,
        group   => $ora_group,
        mode    => $mode,
        require => File['/opt/scripts'],
      }
    }

    file { 'showStatus.sh':
      ensure  => present,
      path    => '/opt/scripts/wls/showStatus.sh',
      content => regsubst(template('wls_install/wls/showStatus.sh.erb'), '\r\n', "\n", 'EMG'),
      # content => template('wls_install/wls/showStatus.sh.erb'),
      owner   => $ora_user,
      group   => $ora_group,
      mode    => $mode,
      require => File['/opt/scripts/wls'],
    }

    file { 'stopNodeManager.sh':
      ensure  => present,
      path    => '/opt/scripts/wls/stopNodeManager.sh',
      content => regsubst(template('wls_install/wls/stopNodeManager.sh.erb'), '\r\n', "\n", 'EMG'),
      # content => template('wls_install/wls/stopNodeManager.sh.erb'),
      owner   => $ora_user,
      group   => $ora_group,
      mode    => $mode,
      require => File['/opt/scripts/wls'],
    }

    file { 'cleanOracleEnvironment.sh':
      ensure  => present,
      path    => '/opt/scripts/wls/cleanOracleEnvironment.sh',
      content => regsubst(template('wls_install/cleanOracleEnvironment.sh.erb'), '\r\n', "\n", 'EMG'),
      # content => template('wls_install/cleanOracleEnvironment.sh.erb'),
      owner   => 'root',
      group   => 'root',
      mode    => '0770',
      require => File['/opt/scripts/wls'],
    }

    file { 'startNodeManager.sh':
      ensure  => present,
      path    => '/opt/scripts/wls/startNodeManager.sh',
      content => regsubst(template('wls_install/startNodeManager.sh.erb'), '\r\n', "\n", 'EMG'),
      # content => template('wls_install/startNodeManager.sh.erb'),
      owner   => $ora_user,
      group   => $ora_group,
      mode    => $mode,
      require => File['/opt/scripts/wls'],
    }

    file { 'startWeblogicAdmin.sh':
      ensure  => present,
      path    => '/opt/scripts/wls/startWeblogicAdmin.sh',
      content => regsubst(template('wls_install/startWeblogicAdmin.sh.erb'), '\r\n', "\n", 'EMG'),
      # content => template('wls_install/startWeblogicAdmin.sh.erb'),
      owner   => $ora_user,
      group   => $ora_group,
      mode    => $mode,
      require => File['/opt/scripts/wls'],
    }

    file { 'stopWeblogicAdmin.sh':
      ensure  => present,
      path    => '/opt/scripts/wls/stopWeblogicAdmin.sh',
      content => regsubst(template('wls_install/stopWeblogicAdmin.sh.erb'), '\r\n', "\n", 'EMG'),
      # content => template('wls_install/stopWeblogicAdmin.sh.erb'),
      owner   => $ora_user,
      group   => $ora_group,
      mode    => $mode,
      require => File['/opt/scripts/wls'],
    }

    }
    default: {
      notify{'This operating system is not supported':}
    }
  }
}
