require 'spec_helper'

describe 'wls_install::copydomain', :type => :define do
  let(:title) { 'copy_a_domain' }
  let(:base_params) do
    {
      :version              => 1111,
      :domain_name          => 'test',
      :download_dir         => '/install',
      :os_user              => 'oracle',
      :os_group             => 'dba',
      :middleware_home_dir  => '/opt/oracle/middleware11gR1',
      :weblogic_home_dir    => '/opt/oracle/middleware11gR1/wlserver_103',
      :jdk_home_dir         => '/usr/java/jdk1.7.0_45',
      :adminserver_address  => 'adminserver.com'
    }
  end
  let(:params) { base_params}

  it 'contains resources' do
    is_expected.to compile.with_all_deps
    is_expected.to contain_file('/etc/wls_domains.dat')
    is_expected.to contain_file_line('domain entry for test')
  end

  context 'with use_ssh set to true' do
    let(:params) do
      base_params.merge(:use_ssh => true)
    end

    it 'copies the domain jar using scp' do
      is_expected.to compile.with_all_deps
      copy_action = 'ssh copy domain jar test'
      is_expected.to contain_exec(copy_action)
        .with('command' => 'scp -oStrictHostKeyChecking=no -oCheckHostIP=no oracle@adminserver.com:/install/domain_test.jar /install/domain_test.jar',
              'user'    => 'oracle',
              'group'   => 'dba')
      is_expected.to contain_exec('unpack test').that_requires("Exec[#{copy_action}]")
    end
  end

  context 'using local (NFS) copy' do
    let(:params) do
      base_params.merge(:use_ssh => false)
    end

    it 'copies the domain jar using local copy' do
      is_expected.to compile.with_all_deps
      copy_action = 'local copy domain jar test'
      is_expected.to contain_exec(copy_action)
        .with('command' => 'cp /install/domain_test.jar /install/domain_test.jar',
              'user'    => 'oracle',
              'group'   => 'dba')
      is_expected.to contain_exec('unpack test').that_requires("Exec[#{copy_action}]")
    end
  end

  context 'using copy_script' do
    let(:params) do
      base_params.merge(:copy_script => '/tmp/copy')
    end

    it 'copies the domain jar using local copy' do
      is_expected.to compile.with_all_deps
      copy_action = 'copy with script domain jar test'
      is_expected.to contain_exec(copy_action).with('command' => '/tmp/copy  test.jar /install/domain_test.jar')
      is_expected.to contain_exec('unpack test').that_requires("Exec[#{copy_action}]")
    end
  end
end
